@@ -2281,3 +2281,7 @@ snap_points <- function(x, y, max_dist = 1000) {
     )
     return(out)
 }
+
+rtpois <- function(n, lambda) {
+    qpois(runif(n, dpois(0, lambda), 1), lambda)
+}
